pub struct LogisticRegression {
pub weights: Vector,
pub bias: Vector,
pub activation_fn: ActivationFn,
/* private fields */
}Expand description
A logistic regression model for binary classification.
This model uses a linear combination of features and weights, followed by an activation function, to predict the probability of an input belonging to a positive class.
Fields
weights: VectorModel weights for each feature
bias: VectorBias term (intercept)
activation_fn: ActivationFnActivation function used for prediction
Implementations
Sourceimpl LogisticRegression
impl LogisticRegression
Sourcepub fn new(
n_features: usize,
activation_fn: ActivationFn,
threshold: f64,
) -> Self
pub fn new( n_features: usize, activation_fn: ActivationFn, threshold: f64, ) -> Self
Sourcepub fn builder() -> LogisticRegressionBuilder
pub fn builder() -> LogisticRegressionBuilder
Returns a builder for creating LogisticRegression models with custom configurations.
Returns
A new LogisticRegressionBuilder instance