GradientDescent

Struct GradientDescent 

pub struct GradientDescent<Input, Output, M: OptimizableModel<Input, Output>> {
    pub cost_history: Vec<f64>,
    /* private fields */
}
A standard gradient descent optimizer.

Gradient descent is an optim algorithm that iteratively adjusts parameters to minimize a cost function by moving in the direction of the steepest decrease in the cost function.

Fields

  • learning_rate - The step size for each iteration of gradient descent
  • epochs - The number of complete passes through the training dataset
  • cost_history - Records the cost value after each parameter update

Fields

cost_history: Vec<f64>

Implementations

Source

impl<Input, Output, M: OptimizableModel<Input, Output>> GradientDescent<Input, Output, M>

pub fn new(learning_rate: f64, epochs: usize) -> Self

Creates a new GradientDescent optimizer.

Arguments
  • learning_rate - The step size for each parameter update
  • epochs - The number of complete passes through the training dataset
Returns

A new GradientDescent instance