pub struct GradientDescent<Input, Output, M: OptimizableModel<Input, Output>> {
pub cost_history: Vec<f64>,
/* private fields */
}Expand description
A standard gradient descent optimizer.
Gradient descent is an optim algorithm that iteratively adjusts parameters to minimize a cost function by moving in the direction of the steepest decrease in the cost function.
Fields
learning_rate- The step size for each iteration of gradient descentepochs- The number of complete passes through the training datasetcost_history- Records the cost value after each parameter update
Fields
cost_history: Vec<f64>Implementations
Sourceimpl<Input, Output, M: OptimizableModel<Input, Output>> GradientDescent<Input, Output, M>
impl<Input, Output, M: OptimizableModel<Input, Output>> GradientDescent<Input, Output, M>